# Copyright (c) 2005, 2006, 2007, 2008 Diego "Flameeyes" Pettenò
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# This plugin requires ruby-hunspell extension, that you can find at
# http://flameeyes.is-a-geek.org/projects#ruby-hunspell

require 'hunspell'

class HunspellPlugin < Plugin
  BotConfig.register BotConfigStringValue.new('hunspell.dictionary_file',
    :default => "/usr/share/myspell/en_GB.dic",
    :desc => "Dictionary file to pass to hunspell library.")
  BotConfig.register BotConfigStringValue.new('hunspell.affix_file',
    :default => "/usr/share/myspell/en_GB.aff",
    :desc => "Affix file to pass to hunspell library.")

  def help(plugin, topic="")
    "spell #{Bold}word#{Bold} : check spelling of word, suggest alternatives"
  end

  def spell(m, params)
    suggest(m, params[:word])
  end

  def suggest(m, word)
    h = Hunspell::Hunspell.new(@bot.config["hunspell.affix_file"].to_s, @bot.config["hunspell.dictionary_file"].to_s)
    if h.spell(word)
      m.reply "#{word} may be spelt correctly"
      return
    else
      suggs = h.suggest(word)
      if suggs.empty?
        m.reply "#{word}: no suggestions"
        return
      else
        m.reply "#{word}: #{suggs.join(', ')}"
        return
      end
    end
  end

  def listen(m)
    if m.message =~ /(\b[a-z]+)\(sp\?\)/
      suggest(m, $1)
    end
  end

  def link_source(m, params)
    m.reply "http://flameeyes.is-a-geek.org/projects#rbot-hunspell"
  end

  def show_credits(m, params)
    m.reply "Copyright (C) 2005-2008 Diego Pettenò. Distributed under Affero General Public License version 3."
  end
end

plugin = HunspellPlugin.new

plugin.map 'spell :word',
  :action => 'suggest'

plugin.map 'spellsources',
  :action => 'link_source'

plugin.map 'spellcredits',
  :action => 'show_credits'
